@@ -12,7 +12,7 @@ from wedeliver_core.helpers.get_prefix import get_prefix
 
 def route(path, methods=["GET"], schema=None, many=False, allowed_roles=None, require_auth=True,
           append_auth_args=None):
-    app = WeDeliverCore.getApp()
+    app = WeDeliverCore.get_app()
 
     def factory(func):
         @app.route(path, methods=methods)
